# Django-media-pil

Simple widget for image manipulations by pillow in the Django Admin.


## Installation

To install the package by `pip` run following command

```sh
$ pip install git+https://github.com/giorgi94/django-media-pil.git
```
